# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_dnszones.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,azure/azure_microsoft_network_dnszones.proto\x12,oak9.tython.azure.microsoft_network_dnszones\x1a\x13shared/shared.proto\"\xb5\x01\n\x1aMicrosoft_Network_dnsZones\x12I\n\tdns_zones\x18\x01 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.DnsZones\x12L\n\x0b\x64ns_zones_a\x18\x02 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.DnsZonesA\"\x9c\x08\n\x0b\x44nsZonesTXT\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesTXT.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesSRV\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSRV.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesSOA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSOA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesPTR\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesPTR.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x08\n\nDnsZonesNS\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12X\n\x08metadata\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_dnszones.DnsZonesNS.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x08\n\nDnsZonesMX\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12X\n\x08metadata\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_dnszones.DnsZonesMX.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x08\n\rDnsZonesCNAME\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12[\n\x08metadata\x18\x04 \x03(\x0b\x32I.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCNAME.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x08\n\x0b\x44nsZonesCAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Y\n\x08metadata\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x08\n\x0c\x44nsZonesAAAA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12Z\n\x08metadata\x18\x04 \x03(\x0b\x32H.oak9.tython.azure.microsoft_network_dnszones.DnsZonesAAAA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x08\n\tDnsZonesA\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12W\n\x08metadata\x18\x04 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_network_dnszones.DnsZonesA.MetadataEntry\x12\x0b\n\x03ttl\x18\x05 \x01(\x05\x12\x17\n\x0ftarget_resource\x18\x06 \x01(\t\x12H\n\ta_records\x18\x07 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_network_dnszones.ARecord\x12N\n\x0c\x61\x61\x61\x61_records\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.AaaaRecord\x12J\n\nmx_records\x18\t \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.MxRecord\x12J\n\nns_records\x18\n \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_dnszones.NsRecord\x12L\n\x0bptr_records\x18\x0b \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.PtrRecord\x12L\n\x0bsrv_records\x18\x0c \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SrvRecord\x12L\n\x0btxt_records\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.TxtRecord\x12O\n\x0c\x63name_record\x18\x0e \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.CnameRecord\x12K\n\nsoa_record\x18\x0f \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.SoaRecord\x12L\n\x0b\x63\x61\x61_records\x18\x10 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_network_dnszones.CaaRecord\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\tCaaRecord\x12\r\n\x05\x66lags\x18\x01 \x01(\x05\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x93\x01\n\tSoaRecord\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\x05\x12\x14\n\x0crefresh_time\x18\x04 \x01(\x05\x12\x12\n\nretry_time\x18\x05 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x06 \x01(\x05\x12\x13\n\x0bminimum_ttl\x18\x07 \x01(\x05\"\x1c\n\x0b\x43nameRecord\x12\r\n\x05\x63name\x18\x01 \x01(\t\"\x1a\n\tTxtRecord\x12\r\n\x05value\x18\x01 \x03(\t\"K\n\tSrvRecord\x12\x10\n\x08priority\x18\x01 \x01(\x05\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0e\n\x06target\x18\x04 \x01(\t\"\x1d\n\tPtrRecord\x12\x10\n\x08ptrdname\x18\x01 \x01(\t\"\x1b\n\x08NsRecord\x12\x0f\n\x07nsdname\x18\x01 \x01(\t\"0\n\x08MxRecord\x12\x12\n\npreference\x18\x01 \x01(\x05\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\"\"\n\nAaaaRecord\x12\x14\n\x0cipv6_address\x18\x01 \x01(\t\"\x1f\n\x07\x41Record\x12\x14\n\x0cipv4_address\x18\x01 \x01(\t\"\xbb\x08\n\x08\x44nsZones\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12N\n\x04tags\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_network_dnszones.DnsZones.TagsEntry\x12\x0c\n\x04\x65tag\x18\x05 \x01(\t\x12\x11\n\tzone_type\x18\x06 \x01(\t\x12%\n\x1dregistration_virtual_networks\x18\x07 \x03(\t\x12#\n\x1bresolution_virtual_networks\x18\x08 \x03(\t\x12Q\n\x0e\x64ns_zones__txt\x18\t \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesTXT\x12Q\n\x0e\x64ns_zones__srv\x18\n \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSRV\x12Q\n\x0e\x64ns_zones__soa\x18\x0b \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesSOA\x12Q\n\x0e\x64ns_zones__ptr\x18\x0c \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesPTR\x12O\n\rdns_zones__ns\x18\r \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.DnsZonesNS\x12O\n\rdns_zones__mx\x18\x0e \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_network_dnszones.DnsZonesMX\x12U\n\x10\x64ns_zones__cname\x18\x0f \x03(\x0b\x32;.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCNAME\x12R\n\x0f\x64ns_zones__ca_a\x18\x10 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_network_dnszones.DnsZonesCAA\x12S\n\x0f\x64ns_zones__aaaa\x18\x11 \x03(\x0b\x32:.oak9.tython.azure.microsoft_network_dnszones.DnsZonesAAAA\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_dnszones_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DNSZONESTXT_METADATAENTRY._options = None
  _DNSZONESTXT_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESSRV_METADATAENTRY._options = None
  _DNSZONESSRV_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESSOA_METADATAENTRY._options = None
  _DNSZONESSOA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESPTR_METADATAENTRY._options = None
  _DNSZONESPTR_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESNS_METADATAENTRY._options = None
  _DNSZONESNS_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESMX_METADATAENTRY._options = None
  _DNSZONESMX_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESCNAME_METADATAENTRY._options = None
  _DNSZONESCNAME_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESCAA_METADATAENTRY._options = None
  _DNSZONESCAA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESAAAA_METADATAENTRY._options = None
  _DNSZONESAAAA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONESA_METADATAENTRY._options = None
  _DNSZONESA_METADATAENTRY._serialized_options = b'8\001'
  _DNSZONES_TAGSENTRY._options = None
  _DNSZONES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_DNSZONES._serialized_start=116
  _MICROSOFT_NETWORK_DNSZONES._serialized_end=297
  _DNSZONESTXT._serialized_start=300
  _DNSZONESTXT._serialized_end=1352
  _DNSZONESTXT_METADATAENTRY._serialized_start=1305
  _DNSZONESTXT_METADATAENTRY._serialized_end=1352
  _DNSZONESSRV._serialized_start=1355
  _DNSZONESSRV._serialized_end=2407
  _DNSZONESSRV_METADATAENTRY._serialized_start=1305
  _DNSZONESSRV_METADATAENTRY._serialized_end=1352
  _DNSZONESSOA._serialized_start=2410
  _DNSZONESSOA._serialized_end=3462
  _DNSZONESSOA_METADATAENTRY._serialized_start=1305
  _DNSZONESSOA_METADATAENTRY._serialized_end=1352
  _DNSZONESPTR._serialized_start=3465
  _DNSZONESPTR._serialized_end=4517
  _DNSZONESPTR_METADATAENTRY._serialized_start=1305
  _DNSZONESPTR_METADATAENTRY._serialized_end=1352
  _DNSZONESNS._serialized_start=4520
  _DNSZONESNS._serialized_end=5570
  _DNSZONESNS_METADATAENTRY._serialized_start=1305
  _DNSZONESNS_METADATAENTRY._serialized_end=1352
  _DNSZONESMX._serialized_start=5573
  _DNSZONESMX._serialized_end=6623
  _DNSZONESMX_METADATAENTRY._serialized_start=1305
  _DNSZONESMX_METADATAENTRY._serialized_end=1352
  _DNSZONESCNAME._serialized_start=6626
  _DNSZONESCNAME._serialized_end=7682
  _DNSZONESCNAME_METADATAENTRY._serialized_start=1305
  _DNSZONESCNAME_METADATAENTRY._serialized_end=1352
  _DNSZONESCAA._serialized_start=7685
  _DNSZONESCAA._serialized_end=8737
  _DNSZONESCAA_METADATAENTRY._serialized_start=1305
  _DNSZONESCAA_METADATAENTRY._serialized_end=1352
  _DNSZONESAAAA._serialized_start=8740
  _DNSZONESAAAA._serialized_end=9794
  _DNSZONESAAAA_METADATAENTRY._serialized_start=1305
  _DNSZONESAAAA_METADATAENTRY._serialized_end=1352
  _DNSZONESA._serialized_start=9797
  _DNSZONESA._serialized_end=10845
  _DNSZONESA_METADATAENTRY._serialized_start=1305
  _DNSZONESA_METADATAENTRY._serialized_end=1352
  _CAARECORD._serialized_start=10847
  _CAARECORD._serialized_end=10901
  _SOARECORD._serialized_start=10904
  _SOARECORD._serialized_end=11051
  _CNAMERECORD._serialized_start=11053
  _CNAMERECORD._serialized_end=11081
  _TXTRECORD._serialized_start=11083
  _TXTRECORD._serialized_end=11109
  _SRVRECORD._serialized_start=11111
  _SRVRECORD._serialized_end=11186
  _PTRRECORD._serialized_start=11188
  _PTRRECORD._serialized_end=11217
  _NSRECORD._serialized_start=11219
  _NSRECORD._serialized_end=11246
  _MXRECORD._serialized_start=11248
  _MXRECORD._serialized_end=11296
  _AAAARECORD._serialized_start=11298
  _AAAARECORD._serialized_end=11332
  _ARECORD._serialized_start=11334
  _ARECORD._serialized_end=11365
  _DNSZONES._serialized_start=11368
  _DNSZONES._serialized_end=12451
  _DNSZONES_TAGSENTRY._serialized_start=12408
  _DNSZONES_TAGSENTRY._serialized_end=12451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_bigtable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_bigtable.proto\x12\x18oak9.tython.gcp.bigtable\x1a\x13shared/shared.proto\"a\n\'BigtableAppProfileXSingleClusterRouting\x12\"\n\x1a\x61llow_transactional_writes\x18\x01 \x01(\x08\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"M\n\x1b\x42igtableAppProfileXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xce\x03\n\x12\x42igtableAppProfile\x12\x16\n\x0e\x61pp_profile_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x17\n\x0fignore_warnings\x18\x04 \x01(\x08\x12\x10\n\x08instance\x18\x05 \x01(\t\x12)\n!multi_cluster_routing_cluster_ids\x18\x06 \x03(\t\x12%\n\x1dmulti_cluster_routing_use_any\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x61\n\x16single_cluster_routing\x18\n \x01(\x0b\x32\x41.oak9.tython.gcp.bigtable.BigtableAppProfileXSingleClusterRouting\x12G\n\x08timeouts\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.bigtable.BigtableAppProfileXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n\x17\x42igtableGcPolicyXMaxAge\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x01\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\"-\n\x1b\x42igtableGcPolicyXMaxVersion\x12\x0e\n\x06number\x18\x01 \x01(\x01\"\xd5\x02\n\x10\x42igtableGcPolicy\x12\x15\n\rcolumn_family\x18\x01 \x01(\t\x12\x10\n\x08gc_rules\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rinstance_name\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12\x42\n\x07max_age\x18\x08 \x01(\x0b\x32\x31.oak9.tython.gcp.bigtable.BigtableGcPolicyXMaxAge\x12J\n\x0bmax_version\x18\t \x03(\x0b\x32\x35.oak9.tython.gcp.bigtable.BigtableGcPolicyXMaxVersion\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n*BigtableInstanceXClusterXAutoscalingConfig\x12\x12\n\ncpu_target\x18\x01 \x01(\x01\x12\x11\n\tmax_nodes\x18\x02 \x01(\x01\x12\x11\n\tmin_nodes\x18\x03 \x01(\x01\"\xdd\x01\n\x18\x42igtableInstanceXCluster\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x02 \x01(\t\x12\x11\n\tnum_nodes\x18\x03 \x01(\x01\x12\x14\n\x0cstorage_type\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12`\n\x12\x61utoscaling_config\x18\x06 \x01(\x0b\x32\x44.oak9.tython.gcp.bigtable.BigtableInstanceXClusterXAutoscalingConfig\"\xfc\x02\n\x10\x42igtableInstance\x12\x1b\n\x13\x64\x65letion_protection\x18\x01 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rinstance_type\x18\x04 \x01(\t\x12\x46\n\x06labels\x18\x05 \x03(\x0b\x32\x36.oak9.tython.gcp.bigtable.BigtableInstance.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x43\n\x07\x63luster\x18\x08 \x03(\x0b\x32\x32.oak9.tython.gcp.bigtable.BigtableInstanceXCluster\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$BigtableInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x84\x02\n\x1a\x42igtableInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.bigtable.BigtableInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#BigtableInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x19\x42igtableInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.bigtable.BigtableInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x01\n\x19\x42igtableInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\",\n\x1a\x42igtableTableXColumnFamily\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\"\xeb\x01\n\rBigtableTable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nsplit_keys\x18\x05 \x03(\t\x12K\n\rcolumn_family\x18\x06 \x03(\x0b\x32\x34.oak9.tython.gcp.bigtable.BigtableTableXColumnFamily\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!BigtableTableIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x17\x42igtableTableIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12N\n\tcondition\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.bigtable.BigtableTableIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n BigtableTableIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n\x16\x42igtableTableIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.bigtable.BigtableTableIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x01\n\x16\x42igtableTableIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\r\n\x05table\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_bigtable_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BIGTABLEINSTANCE_LABELSENTRY._options = None
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _BIGTABLEAPPPROFILEXSINGLECLUSTERROUTING._serialized_start=73
  _BIGTABLEAPPPROFILEXSINGLECLUSTERROUTING._serialized_end=170
  _BIGTABLEAPPPROFILEXTIMEOUTS._serialized_start=172
  _BIGTABLEAPPPROFILEXTIMEOUTS._serialized_end=249
  _BIGTABLEAPPPROFILE._serialized_start=252
  _BIGTABLEAPPPROFILE._serialized_end=714
  _BIGTABLEGCPOLICYXMAXAGE._serialized_start=716
  _BIGTABLEGCPOLICYXMAXAGE._serialized_end=773
  _BIGTABLEGCPOLICYXMAXVERSION._serialized_start=775
  _BIGTABLEGCPOLICYXMAXVERSION._serialized_end=820
  _BIGTABLEGCPOLICY._serialized_start=823
  _BIGTABLEGCPOLICY._serialized_end=1164
  _BIGTABLEINSTANCEXCLUSTERXAUTOSCALINGCONFIG._serialized_start=1166
  _BIGTABLEINSTANCEXCLUSTERXAUTOSCALINGCONFIG._serialized_end=1268
  _BIGTABLEINSTANCEXCLUSTER._serialized_start=1271
  _BIGTABLEINSTANCEXCLUSTER._serialized_end=1492
  _BIGTABLEINSTANCE._serialized_start=1495
  _BIGTABLEINSTANCE._serialized_end=1875
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_start=1830
  _BIGTABLEINSTANCE_LABELSENTRY._serialized_end=1875
  _BIGTABLEINSTANCEIAMBINDINGXCONDITION._serialized_start=1877
  _BIGTABLEINSTANCEIAMBINDINGXCONDITION._serialized_end=1971
  _BIGTABLEINSTANCEIAMBINDING._serialized_start=1974
  _BIGTABLEINSTANCEIAMBINDING._serialized_end=2234
  _BIGTABLEINSTANCEIAMMEMBERXCONDITION._serialized_start=2236
  _BIGTABLEINSTANCEIAMMEMBERXCONDITION._serialized_end=2329
  _BIGTABLEINSTANCEIAMMEMBER._serialized_start=2332
  _BIGTABLEINSTANCEIAMMEMBER._serialized_end=2589
  _BIGTABLEINSTANCEIAMPOLICY._serialized_start=2592
  _BIGTABLEINSTANCEIAMPOLICY._serialized_end=2758
  _BIGTABLETABLEXCOLUMNFAMILY._serialized_start=2760
  _BIGTABLETABLEXCOLUMNFAMILY._serialized_end=2804
  _BIGTABLETABLE._serialized_start=2807
  _BIGTABLETABLE._serialized_end=3042
  _BIGTABLETABLEIAMBINDINGXCONDITION._serialized_start=3044
  _BIGTABLETABLEIAMBINDINGXCONDITION._serialized_end=3135
  _BIGTABLETABLEIAMBINDING._serialized_start=3138
  _BIGTABLETABLEIAMBINDING._serialized_end=3407
  _BIGTABLETABLEIAMMEMBERXCONDITION._serialized_start=3409
  _BIGTABLETABLEIAMMEMBERXCONDITION._serialized_end=3499
  _BIGTABLETABLEIAMMEMBER._serialized_start=3502
  _BIGTABLETABLEIAMMEMBER._serialized_end=3768
  _BIGTABLETABLEIAMPOLICY._serialized_start=3771
  _BIGTABLETABLEIAMPOLICY._serialized_end=3949
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_organization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_organization.proto\x12\x1coak9.tython.gcp.organization\x1a\x13shared/shared.proto\"f\n3OrganizationAccessApprovalSettingsXEnrolledServices\x12\x15\n\rcloud_product\x18\x01 \x01(\t\x12\x18\n\x10\x65nrollment_level\x18\x02 \x01(\t\"]\n+OrganizationAccessApprovalSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf5\x03\n\"OrganizationAccessApprovalSettings\x12\x1a\n\x12\x61\x63tive_key_version\x18\x01 \x01(\t\x12\'\n\x1f\x61ncestor_has_active_key_version\x18\x02 \x01(\x08\x12\x19\n\x11\x65nrolled_ancestor\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1b\n\x13invalid_key_version\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13notification_emails\x18\x07 \x03(\t\x12\x17\n\x0forganization_id\x18\x08 \x01(\t\x12l\n\x11\x65nrolled_services\x18\t \x03(\x0b\x32Q.oak9.tython.gcp.organization.OrganizationAccessApprovalSettingsXEnrolledServices\x12[\n\x08timeouts\x18\n \x01(\x0b\x32I.oak9.tython.gcp.organization.OrganizationAccessApprovalSettingsXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n)OrganizationIamAuditConfigXAuditLogConfig\x12\x18\n\x10\x65xempted_members\x18\x01 \x03(\t\x12\x10\n\x08log_type\x18\x02 \x01(\t\"\xf3\x01\n\x1aOrganizationIamAuditConfig\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x61\n\x10\x61udit_log_config\x18\x05 \x03(\x0b\x32G.oak9.tython.gcp.organization.OrganizationIamAuditConfigXAuditLogConfig\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n OrganizationIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xed\x01\n\x16OrganizationIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12Q\n\tcondition\x18\x06 \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe8\x01\n\x19OrganizationIamCustomRole\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x13\n\x0bpermissions\x18\x06 \x03(\t\x12\x0f\n\x07role_id\x18\x07 \x01(\t\x12\r\n\x05stage\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1fOrganizationIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xea\x01\n\x15OrganizationIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12P\n\tcondition\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.organization.OrganizationIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8f\x01\n\x15OrganizationIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"4\n OrganizationPolicyXBooleanPolicy\x12\x10\n\x08\x65nforced\x18\x01 \x01(\x08\"B\n#OrganizationPolicyXListPolicyXAllow\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"A\n\"OrganizationPolicyXListPolicyXDeny\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xf7\x01\n\x1dOrganizationPolicyXListPolicy\x12\x1b\n\x13inherit_from_parent\x18\x01 \x01(\x08\x12\x17\n\x0fsuggested_value\x18\x02 \x01(\t\x12P\n\x05\x61llow\x18\x03 \x01(\x0b\x32\x41.oak9.tython.gcp.organization.OrganizationPolicyXListPolicyXAllow\x12N\n\x04\x64\x65ny\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.organization.OrganizationPolicyXListPolicyXDeny\"3\n OrganizationPolicyXRestorePolicy\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\"[\n\x1bOrganizationPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\x80\x04\n\x12OrganizationPolicy\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x13\n\x0bupdate_time\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\x01\x12V\n\x0e\x62oolean_policy\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationPolicyXBooleanPolicy\x12P\n\x0blist_policy\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.organization.OrganizationPolicyXListPolicy\x12V\n\x0erestore_policy\x18\t \x01(\x0b\x32>.oak9.tython.gcp.organization.OrganizationPolicyXRestorePolicy\x12K\n\x08timeouts\x18\n \x01(\x0b\x32\x39.oak9.tython.gcp.organization.OrganizationPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_organization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORGANIZATIONACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_start=81
  _ORGANIZATIONACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_end=183
  _ORGANIZATIONACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_start=185
  _ORGANIZATIONACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_end=278
  _ORGANIZATIONACCESSAPPROVALSETTINGS._serialized_start=281
  _ORGANIZATIONACCESSAPPROVALSETTINGS._serialized_end=782
  _ORGANIZATIONIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_start=784
  _ORGANIZATIONIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_end=871
  _ORGANIZATIONIAMAUDITCONFIG._serialized_start=874
  _ORGANIZATIONIAMAUDITCONFIG._serialized_end=1117
  _ORGANIZATIONIAMBINDINGXCONDITION._serialized_start=1119
  _ORGANIZATIONIAMBINDINGXCONDITION._serialized_end=1209
  _ORGANIZATIONIAMBINDING._serialized_start=1212
  _ORGANIZATIONIAMBINDING._serialized_end=1449
  _ORGANIZATIONIAMCUSTOMROLE._serialized_start=1452
  _ORGANIZATIONIAMCUSTOMROLE._serialized_end=1684
  _ORGANIZATIONIAMMEMBERXCONDITION._serialized_start=1686
  _ORGANIZATIONIAMMEMBERXCONDITION._serialized_end=1775
  _ORGANIZATIONIAMMEMBER._serialized_start=1778
  _ORGANIZATIONIAMMEMBER._serialized_end=2012
  _ORGANIZATIONIAMPOLICY._serialized_start=2015
  _ORGANIZATIONIAMPOLICY._serialized_end=2158
  _ORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_start=2160
  _ORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_end=2212
  _ORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_start=2214
  _ORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_end=2280
  _ORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_start=2282
  _ORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_end=2347
  _ORGANIZATIONPOLICYXLISTPOLICY._serialized_start=2350
  _ORGANIZATIONPOLICYXLISTPOLICY._serialized_end=2597
  _ORGANIZATIONPOLICYXRESTOREPOLICY._serialized_start=2599
  _ORGANIZATIONPOLICYXRESTOREPOLICY._serialized_end=2650
  _ORGANIZATIONPOLICYXTIMEOUTS._serialized_start=2652
  _ORGANIZATIONPOLICYXTIMEOUTS._serialized_end=2743
  _ORGANIZATIONPOLICY._serialized_start=2746
  _ORGANIZATIONPOLICY._serialized_end=3258
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeGlobalAddressXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalAddressXTimeouts = ComputeGlobalAddressXTimeouts

@typing_extensions.final
class ComputeGlobalAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    address: builtins.str
    address_type: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    ip_version: builtins.str
    name: builtins.str
    network: builtins.str
    prefix_length: builtins.float
    project: builtins.str
    purpose: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalAddressXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        address_type: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ip_version: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        prefix_length: builtins.float = ...,
        project: builtins.str = ...,
        purpose: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeGlobalAddressXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "address_type", b"address_type", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "ip_version", b"ip_version", "name", b"name", "network", b"network", "prefix_length", b"prefix_length", "project", b"project", "purpose", b"purpose", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalAddress = ComputeGlobalAddress

@typing_extensions.final
class ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels = ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels

@typing_extensions.final
class ComputeGlobalForwardingRuleXMetadataFilters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_MATCH_CRITERIA_FIELD_NUMBER: builtins.int
    FILTER_LABELS_FIELD_NUMBER: builtins.int
    filter_match_criteria: builtins.str
    @property
    def filter_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels]: ...
    def __init__(
        self,
        *,
        filter_match_criteria: builtins.str = ...,
        filter_labels: collections.abc.Iterable[global___ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_labels", b"filter_labels", "filter_match_criteria", b"filter_match_criteria"]) -> None: ...

global___ComputeGlobalForwardingRuleXMetadataFilters = ComputeGlobalForwardingRuleXMetadataFilters

@typing_extensions.final
class ComputeGlobalForwardingRuleXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeGlobalForwardingRuleXTimeouts = ComputeGlobalForwardingRuleXTimeouts

@typing_extensions.final
class ComputeGlobalForwardingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PORT_RANGE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_ID_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_STATUS_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    METADATA_FILTERS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    ip_address: builtins.str
    ip_protocol: builtins.str
    ip_version: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    load_balancing_scheme: builtins.str
    name: builtins.str
    network: builtins.str
    port_range: builtins.str
    project: builtins.str
    psc_connection_id: builtins.str
    psc_connection_status: builtins.str
    self_link: builtins.str
    target: builtins.str
    @property
    def metadata_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeGlobalForwardingRuleXMetadataFilters]: ...
    @property
    def timeouts(self) -> global___ComputeGlobalForwardingRuleXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: builtins.str = ...,
        ip_protocol: builtins.str = ...,
        ip_version: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        load_balancing_scheme: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        port_range: builtins.str = ...,
        project: builtins.str = ...,
        psc_connection_id: builtins.str = ...,
        psc_connection_status: builtins.str = ...,
        self_link: builtins.str = ...,
        target: builtins.str = ...,
        metadata_filters: collections.abc.Iterable[global___ComputeGlobalForwardingRuleXMetadataFilters] | None = ...,
        timeouts: global___ComputeGlobalForwardingRuleXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "ip_address", b"ip_address", "ip_protocol", b"ip_protocol", "ip_version", b"ip_version", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "load_balancing_scheme", b"load_balancing_scheme", "metadata_filters", b"metadata_filters", "name", b"name", "network", b"network", "port_range", b"port_range", "project", b"project", "psc_connection_id", b"psc_connection_id", "psc_connection_status", b"psc_connection_status", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalForwardingRule = ComputeGlobalForwardingRule

@typing_extensions.final
class ComputeGlobalNetworkEndpointXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalNetworkEndpointXTimeouts = ComputeGlobalNetworkEndpointXTimeouts

@typing_extensions.final
class ComputeGlobalNetworkEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    GLOBAL_NETWORK_ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    global_network_endpoint_group: builtins.str
    id: builtins.str
    ip_address: builtins.str
    port: builtins.float
    project: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalNetworkEndpointXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        global_network_endpoint_group: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        timeouts: global___ComputeGlobalNetworkEndpointXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdn", b"fqdn", "global_network_endpoint_group", b"global_network_endpoint_group", "id", b"id", "ip_address", b"ip_address", "port", b"port", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalNetworkEndpoint = ComputeGlobalNetworkEndpoint

@typing_extensions.final
class ComputeGlobalNetworkEndpointGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeGlobalNetworkEndpointGroupXTimeouts = ComputeGlobalNetworkEndpointGroupXTimeouts

@typing_extensions.final
class ComputeGlobalNetworkEndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_PORT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_port: builtins.float
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network_endpoint_type: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeGlobalNetworkEndpointGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_port: builtins.float = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network_endpoint_type: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeGlobalNetworkEndpointGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_port", b"default_port", "description", b"description", "id", b"id", "name", b"name", "network_endpoint_type", b"network_endpoint_type", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeGlobalNetworkEndpointGroup = ComputeGlobalNetworkEndpointGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ScalableTargetScalableTargetAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_capacity: builtins.int
    min_capacity: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_capacity: builtins.int = ...,
        min_capacity: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "resource_info", b"resource_info"]) -> None: ...

global___ScalableTargetScalableTargetAction = ScalableTargetScalableTargetAction

@typing_extensions.final
class ScalableTargetScheduledAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    SCALABLE_TARGET_ACTION_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SCHEDULED_ACTION_NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    end_time: builtins.str
    @property
    def scalable_target_action(self) -> global___ScalableTargetScalableTargetAction: ...
    schedule: builtins.str
    scheduled_action_name: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        end_time: builtins.str = ...,
        scalable_target_action: global___ScalableTargetScalableTargetAction | None = ...,
        schedule: builtins.str = ...,
        scheduled_action_name: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scalable_target_action", b"scalable_target_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "resource_info", b"resource_info", "scalable_target_action", b"scalable_target_action", "schedule", b"schedule", "scheduled_action_name", b"scheduled_action_name", "start_time", b"start_time"]) -> None: ...

global___ScalableTargetScheduledAction = ScalableTargetScheduledAction

@typing_extensions.final
class ScalableTargetSuspendedState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DYNAMIC_SCALING_IN_SUSPENDED_FIELD_NUMBER: builtins.int
    DYNAMIC_SCALING_OUT_SUSPENDED_FIELD_NUMBER: builtins.int
    SCHEDULED_SCALING_SUSPENDED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dynamic_scaling_in_suspended: builtins.bool
    dynamic_scaling_out_suspended: builtins.bool
    scheduled_scaling_suspended: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dynamic_scaling_in_suspended: builtins.bool = ...,
        dynamic_scaling_out_suspended: builtins.bool = ...,
        scheduled_scaling_suspended: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_scaling_in_suspended", b"dynamic_scaling_in_suspended", "dynamic_scaling_out_suspended", b"dynamic_scaling_out_suspended", "resource_info", b"resource_info", "scheduled_scaling_suspended", b"scheduled_scaling_suspended"]) -> None: ...

global___ScalableTargetSuspendedState = ScalableTargetSuspendedState

@typing_extensions.final
class ScalableTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SCALABLE_DIMENSION_FIELD_NUMBER: builtins.int
    SCHEDULED_ACTIONS_FIELD_NUMBER: builtins.int
    SERVICE_NAMESPACE_FIELD_NUMBER: builtins.int
    SUSPENDED_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_capacity: builtins.int
    min_capacity: builtins.int
    resource_id: builtins.str
    role_arn: builtins.str
    scalable_dimension: builtins.str
    @property
    def scheduled_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalableTargetScheduledAction]: ...
    service_namespace: builtins.str
    @property
    def suspended_state(self) -> global___ScalableTargetSuspendedState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_capacity: builtins.int = ...,
        min_capacity: builtins.int = ...,
        resource_id: builtins.str = ...,
        role_arn: builtins.str = ...,
        scalable_dimension: builtins.str = ...,
        scheduled_actions: collections.abc.Iterable[global___ScalableTargetScheduledAction] | None = ...,
        service_namespace: builtins.str = ...,
        suspended_state: global___ScalableTargetSuspendedState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "suspended_state", b"suspended_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "resource_id", b"resource_id", "resource_info", b"resource_info", "role_arn", b"role_arn", "scalable_dimension", b"scalable_dimension", "scheduled_actions", b"scheduled_actions", "service_namespace", b"service_namespace", "suspended_state", b"suspended_state"]) -> None: ...

global___ScalableTarget = ScalableTarget

@typing_extensions.final
class ApplicationAutoScaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALABLE_TARGET_FIELD_NUMBER: builtins.int
    SCALING_POLICY_FIELD_NUMBER: builtins.int
    @property
    def scalable_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalableTarget]: ...
    @property
    def scaling_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPolicy]: ...
    def __init__(
        self,
        *,
        scalable_target: collections.abc.Iterable[global___ScalableTarget] | None = ...,
        scaling_policy: collections.abc.Iterable[global___ScalingPolicy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scalable_target", b"scalable_target", "scaling_policy", b"scaling_policy"]) -> None: ...

global___ApplicationAutoScaling = ApplicationAutoScaling

@typing_extensions.final
class ScalingPolicyStepAdjustment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_INTERVAL_LOWER_BOUND_FIELD_NUMBER: builtins.int
    METRIC_INTERVAL_UPPER_BOUND_FIELD_NUMBER: builtins.int
    SCALING_ADJUSTMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_interval_lower_bound: builtins.float
    metric_interval_upper_bound: builtins.float
    scaling_adjustment: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_interval_lower_bound: builtins.float = ...,
        metric_interval_upper_bound: builtins.float = ...,
        scaling_adjustment: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_interval_lower_bound", b"metric_interval_lower_bound", "metric_interval_upper_bound", b"metric_interval_upper_bound", "resource_info", b"resource_info", "scaling_adjustment", b"scaling_adjustment"]) -> None: ...

global___ScalingPolicyStepAdjustment = ScalingPolicyStepAdjustment

@typing_extensions.final
class ScalingPolicyStepScalingPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADJUSTMENT_TYPE_FIELD_NUMBER: builtins.int
    COOLDOWN_FIELD_NUMBER: builtins.int
    METRIC_AGGREGATION_TYPE_FIELD_NUMBER: builtins.int
    MIN_ADJUSTMENT_MAGNITUDE_FIELD_NUMBER: builtins.int
    STEP_ADJUSTMENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    adjustment_type: builtins.str
    cooldown: builtins.int
    metric_aggregation_type: builtins.str
    min_adjustment_magnitude: builtins.int
    @property
    def step_adjustments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPolicyStepAdjustment]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        adjustment_type: builtins.str = ...,
        cooldown: builtins.int = ...,
        metric_aggregation_type: builtins.str = ...,
        min_adjustment_magnitude: builtins.int = ...,
        step_adjustments: collections.abc.Iterable[global___ScalingPolicyStepAdjustment] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adjustment_type", b"adjustment_type", "cooldown", b"cooldown", "metric_aggregation_type", b"metric_aggregation_type", "min_adjustment_magnitude", b"min_adjustment_magnitude", "resource_info", b"resource_info", "step_adjustments", b"step_adjustments"]) -> None: ...

global___ScalingPolicyStepScalingPolicyConfiguration = ScalingPolicyStepScalingPolicyConfiguration

@typing_extensions.final
class ScalingPolicyMetricDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ScalingPolicyMetricDimension = ScalingPolicyMetricDimension

@typing_extensions.final
class ScalingPolicyCustomizedMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DIMENSIONS_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    STATISTIC_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def dimensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScalingPolicyMetricDimension]: ...
    metric_name: builtins.str
    namespace: builtins.str
    statistic: builtins.str
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dimensions: collections.abc.Iterable[global___ScalingPolicyMetricDimension] | None = ...,
        metric_name: builtins.str = ...,
        namespace: builtins.str = ...,
        statistic: builtins.str = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dimensions", b"dimensions", "metric_name", b"metric_name", "namespace", b"namespace", "resource_info", b"resource_info", "statistic", b"statistic", "unit", b"unit"]) -> None: ...

global___ScalingPolicyCustomizedMetricSpecification = ScalingPolicyCustomizedMetricSpecification

@typing_extensions.final
class ScalingPolicyPredefinedMetricSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PREDEFINED_METRIC_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_LABEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    predefined_metric_type: builtins.str
    resource_label: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        predefined_metric_type: builtins.str = ...,
        resource_label: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["predefined_metric_type", b"predefined_metric_type", "resource_info", b"resource_info", "resource_label", b"resource_label"]) -> None: ...

global___ScalingPolicyPredefinedMetricSpecification = ScalingPolicyPredefinedMetricSpecification

@typing_extensions.final
class ScalingPolicyTargetTrackingScalingPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CUSTOMIZED_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    DISABLE_SCALE_IN_FIELD_NUMBER: builtins.int
    PREDEFINED_METRIC_SPECIFICATION_FIELD_NUMBER: builtins.int
    SCALE_IN_COOLDOWN_FIELD_NUMBER: builtins.int
    SCALE_OUT_COOLDOWN_FIELD_NUMBER: builtins.int
    TARGET_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def customized_metric_specification(self) -> global___ScalingPolicyCustomizedMetricSpecification: ...
    disable_scale_in: builtins.bool
    @property
    def predefined_metric_specification(self) -> global___ScalingPolicyPredefinedMetricSpecification: ...
    scale_in_cooldown: builtins.int
    scale_out_cooldown: builtins.int
    target_value: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        customized_metric_specification: global___ScalingPolicyCustomizedMetricSpecification | None = ...,
        disable_scale_in: builtins.bool = ...,
        predefined_metric_specification: global___ScalingPolicyPredefinedMetricSpecification | None = ...,
        scale_in_cooldown: builtins.int = ...,
        scale_out_cooldown: builtins.int = ...,
        target_value: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customized_metric_specification", b"customized_metric_specification", "predefined_metric_specification", b"predefined_metric_specification", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customized_metric_specification", b"customized_metric_specification", "disable_scale_in", b"disable_scale_in", "predefined_metric_specification", b"predefined_metric_specification", "resource_info", b"resource_info", "scale_in_cooldown", b"scale_in_cooldown", "scale_out_cooldown", b"scale_out_cooldown", "target_value", b"target_value"]) -> None: ...

global___ScalingPolicyTargetTrackingScalingPolicyConfiguration = ScalingPolicyTargetTrackingScalingPolicyConfiguration

@typing_extensions.final
class ScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SCALABLE_DIMENSION_FIELD_NUMBER: builtins.int
    SCALING_TARGET_ID_FIELD_NUMBER: builtins.int
    SERVICE_NAMESPACE_FIELD_NUMBER: builtins.int
    STEP_SCALING_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    TARGET_TRACKING_SCALING_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    policy_name: builtins.str
    policy_type: builtins.str
    resource_id: builtins.str
    scalable_dimension: builtins.str
    scaling_target_id: builtins.str
    service_namespace: builtins.str
    @property
    def step_scaling_policy_configuration(self) -> global___ScalingPolicyStepScalingPolicyConfiguration: ...
    @property
    def target_tracking_scaling_policy_configuration(self) -> global___ScalingPolicyTargetTrackingScalingPolicyConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy_name: builtins.str = ...,
        policy_type: builtins.str = ...,
        resource_id: builtins.str = ...,
        scalable_dimension: builtins.str = ...,
        scaling_target_id: builtins.str = ...,
        service_namespace: builtins.str = ...,
        step_scaling_policy_configuration: global___ScalingPolicyStepScalingPolicyConfiguration | None = ...,
        target_tracking_scaling_policy_configuration: global___ScalingPolicyTargetTrackingScalingPolicyConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "step_scaling_policy_configuration", b"step_scaling_policy_configuration", "target_tracking_scaling_policy_configuration", b"target_tracking_scaling_policy_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_name", b"policy_name", "policy_type", b"policy_type", "resource_id", b"resource_id", "resource_info", b"resource_info", "scalable_dimension", b"scalable_dimension", "scaling_target_id", b"scaling_target_id", "service_namespace", b"service_namespace", "step_scaling_policy_configuration", b"step_scaling_policy_configuration", "target_tracking_scaling_policy_configuration", b"target_tracking_scaling_policy_configuration"]) -> None: ...

global___ScalingPolicy = ScalingPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_billing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_billing.proto\x12\x17oak9.tython.gcp.billing\x1a\x13shared/shared.proto\"\\\n\"BillingAccountIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf8\x01\n\x18\x42illingAccountIamBinding\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12N\n\tcondition\x18\x06 \x01(\x0b\x32;.oak9.tython.gcp.billing.BillingAccountIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!BillingAccountIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x17\x42illingAccountIamMember\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.billing.BillingAccountIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x17\x42illingAccountIamPolicy\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n\x1c\x42illingBudgetXAllUpdatesRule\x12&\n\x1e\x64isable_default_iam_recipients\x18\x01 \x01(\x08\x12(\n monitoring_notification_channels\x18\x02 \x03(\t\x12\x14\n\x0cpubsub_topic\x18\x03 \x01(\t\x12\x16\n\x0eschema_version\x18\x04 \x01(\t\"[\n$BillingBudgetXAmountXSpecifiedAmount\x12\x15\n\rcurrency_code\x18\x01 \x01(\t\x12\r\n\x05nanos\x18\x02 \x01(\x01\x12\r\n\x05units\x18\x03 \x01(\t\"\x8b\x01\n\x14\x42illingBudgetXAmount\x12\x1a\n\x12last_period_amount\x18\x01 \x01(\x08\x12W\n\x10specified_amount\x18\x02 \x01(\x0b\x32=.oak9.tython.gcp.billing.BillingBudgetXAmountXSpecifiedAmount\"[\n/BillingBudgetXBudgetFilterXCustomPeriodXEndDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"]\n1BillingBudgetXBudgetFilterXCustomPeriodXStartDate\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\r\n\x05month\x18\x02 \x01(\x01\x12\x0c\n\x04year\x18\x03 \x01(\x01\"\xe5\x01\n\'BillingBudgetXBudgetFilterXCustomPeriod\x12Z\n\x08\x65nd_date\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriodXEndDate\x12^\n\nstart_date\x18\x02 \x01(\x0b\x32J.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriodXStartDate\"\xfd\x02\n\x1a\x42illingBudgetXBudgetFilter\x12\x17\n\x0f\x63\x61lendar_period\x18\x01 \x01(\t\x12\x14\n\x0c\x63redit_types\x18\x02 \x03(\t\x12\x1e\n\x16\x63redit_types_treatment\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.billing.BillingBudgetXBudgetFilter.LabelsEntry\x12\x10\n\x08projects\x18\x05 \x03(\t\x12\x10\n\x08services\x18\x06 \x03(\t\x12\x13\n\x0bsubaccounts\x18\x07 \x03(\t\x12W\n\rcustom_period\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.billing.BillingBudgetXBudgetFilterXCustomPeriod\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1c\x42illingBudgetXThresholdRules\x12\x13\n\x0bspend_basis\x18\x01 \x01(\t\x12\x19\n\x11threshold_percent\x18\x02 \x01(\x01\"H\n\x16\x42illingBudgetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x04\n\rBillingBudget\x12\x17\n\x0f\x62illing_account\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12O\n\x10\x61ll_updates_rule\x18\x05 \x01(\x0b\x32\x35.oak9.tython.gcp.billing.BillingBudgetXAllUpdatesRule\x12=\n\x06\x61mount\x18\x06 \x01(\x0b\x32-.oak9.tython.gcp.billing.BillingBudgetXAmount\x12J\n\rbudget_filter\x18\x07 \x01(\x0b\x32\x33.oak9.tython.gcp.billing.BillingBudgetXBudgetFilter\x12N\n\x0fthreshold_rules\x18\x08 \x03(\x0b\x32\x35.oak9.tython.gcp.billing.BillingBudgetXThresholdRules\x12\x41\n\x08timeouts\x18\t \x01(\x0b\x32/.oak9.tython.gcp.billing.BillingBudgetXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x01\n\x11\x42illingSubaccount\x12\x1a\n\x12\x62illing_account_id\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65letion_policy\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1e\n\x16master_billing_account\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04open\x18\x07 \x01(\x08\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_billing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._options = None
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_options = b'8\001'
  _BILLINGACCOUNTIAMBINDINGXCONDITION._serialized_start=71
  _BILLINGACCOUNTIAMBINDINGXCONDITION._serialized_end=163
  _BILLINGACCOUNTIAMBINDING._serialized_start=166
  _BILLINGACCOUNTIAMBINDING._serialized_end=414
  _BILLINGACCOUNTIAMMEMBERXCONDITION._serialized_start=416
  _BILLINGACCOUNTIAMMEMBERXCONDITION._serialized_end=507
  _BILLINGACCOUNTIAMMEMBER._serialized_start=510
  _BILLINGACCOUNTIAMMEMBER._serialized_end=755
  _BILLINGACCOUNTIAMPOLICY._serialized_start=758
  _BILLINGACCOUNTIAMPOLICY._serialized_end=915
  _BILLINGBUDGETXALLUPDATESRULE._serialized_start=918
  _BILLINGBUDGETXALLUPDATESRULE._serialized_end=1076
  _BILLINGBUDGETXAMOUNTXSPECIFIEDAMOUNT._serialized_start=1078
  _BILLINGBUDGETXAMOUNTXSPECIFIEDAMOUNT._serialized_end=1169
  _BILLINGBUDGETXAMOUNT._serialized_start=1172
  _BILLINGBUDGETXAMOUNT._serialized_end=1311
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXENDDATE._serialized_start=1313
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXENDDATE._serialized_end=1404
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXSTARTDATE._serialized_start=1406
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIODXSTARTDATE._serialized_end=1499
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIOD._serialized_start=1502
  _BILLINGBUDGETXBUDGETFILTERXCUSTOMPERIOD._serialized_end=1731
  _BILLINGBUDGETXBUDGETFILTER._serialized_start=1734
  _BILLINGBUDGETXBUDGETFILTER._serialized_end=2115
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_start=2070
  _BILLINGBUDGETXBUDGETFILTER_LABELSENTRY._serialized_end=2115
  _BILLINGBUDGETXTHRESHOLDRULES._serialized_start=2117
  _BILLINGBUDGETXTHRESHOLDRULES._serialized_end=2195
  _BILLINGBUDGETXTIMEOUTS._serialized_start=2197
  _BILLINGBUDGETXTIMEOUTS._serialized_end=2269
  _BILLINGBUDGET._serialized_start=2272
  _BILLINGBUDGET._serialized_end=2784
  _BILLINGSUBACCOUNT._serialized_start=2787
  _BILLINGSUBACCOUNT._serialized_end=3010
# @@protoc_insertion_point(module_scope)
